@@ -121,7 +121,7 @@ class DBConn:
             conn.close()
             return rownum
     
-        # 执行SELECT语句
+        # 执行SELECT语句，会一次性把结果全拿到内存里，数据量大慎用
         if sql.lower().strip().startswith("select"):
             sql = sql.strip()
             col = []
@@ -132,9 +132,17 @@ class DBConn:
             for c in cur.description:
                 col.append(c[0])
             rows = cur.fetchall()
+            rows_new = []
+            for row in rows:
+                row_new = []
+                for cell in row:
+                    cell_new = str(cell)
+                    row_new.append(cell_new)
+                rows_new.append(row_new)
+            qrs = QueryResults(tuple(col), rows_new)
             cur.close()
             conn.close()
-            return QueryResults(tuple(col), rows)
+            return qrs
         
     def run(self, sql, param=None, wait=False):
         """ 执行点什么
