@@ -60,7 +60,7 @@ class OracleTools:
             else:
                 nullable = ''
             if col_[3] != 'None':
-                data_default = ' default ' + col_[3]
+                data_default = ' default ' + col_[3].strip('\n')
             else:
                 data_default = ''
             mess = mess + 'column: ' + colstr.lower() + nullable + data_default + '\n'
@@ -86,7 +86,7 @@ class OracleTools:
             and t2.index_name = t3.index_name(+)
             and t2.table_name = t3.table_name(+)
             and t2.column_position = t3.column_position(+)
-            order by t2.column_position
+            order by t.index_type, t2.column_position
         '''
         rows = ora_conn.run(sql, (username, table)).get_rows()
         if len(rows) > 0:
@@ -138,6 +138,7 @@ class OracleTools:
                 and t.table_name = t2.table_name
                 and t.constraint_type in('P','U')
             ) group by constraint_name, constraint_type
+            order by constraint_name, constraint_type
         '''
         rss = ora_conn.run(sql, (username, table)).get_rows()
         for rs in rss:
@@ -164,9 +165,19 @@ class OracleTools:
                                        , str_2=dst_username + '.' + dst_table_name + '\n' + dst_desc
                                        , iscompare=True) + '\n\n'
         return mess, src_desc == dst_desc
-  
+
     @staticmethod
-    def get_ddl(dba_conn, username, table):
+    def get_ddl(dba_conn, username, type_, obj_name):
+        username = username.upper()
+        obj_name = obj_name.upper()
+        type_ = type_.upper()
+        sql = '''
+            select dbms_metadata.get_ddl(?, ?, ?) from dual
+        '''
+        return dba_conn.run(sql, (type_, obj_name, username)).get_rows()[0][0]
+
+    @staticmethod
+    def get_table_ddl(dba_conn, username, table):
         ddl_sqls = ''
         sql = '''
             select * from (
@@ -180,7 +191,7 @@ class OracleTools:
         for row in rows:
             type_ = row[3]
             name = row[2]
-            ddl_sql = OracleTools.get_ddl_by_dbms(dba_conn, username, type_, name) + ';'
+            ddl_sql = OracleTools.get_ddl(dba_conn, username, type_, name) + ';'
             ddl_sqls = ddl_sqls + '-- ' + type_ + ' ' + name + '\n'
             ddl_sql = ddl_sql.lstrip().replace('"', '')
             ddl_sqls = ddl_sqls + ddl_sql + '\n\n'
